@@ -10,9 +10,9 @@ class EquityFuture(Future):
 
     def __init__(self, asset_manager_id, asset_id, settlement_type, contract_size, point_value, tick_size,
                  quote_unit=None, asset_issuer_id=None, asset_status='Active', issue_date=date.min,
-                 expiry_date=date.max, currency=None,
+                 expiry_date=date.max, currency=None, underlying_asset_id=None,
                  display_name='', description='', country_id=None, venue_id=None,
-                 links=None, references=None, *args, **kwargs):
+                 comments=None, links=None, references=None, *args, **kwargs):
         """
 
         :param asset_manager_id: The asset manager who owns the data for this EquityFuture
@@ -34,7 +34,8 @@ class EquityFuture(Future):
                                            point_value=point_value, tick_size=tick_size, quote_unit=quote_unit,
                                            asset_issuer_id=asset_issuer_id, asset_status=asset_status,
                                            display_name=display_name, currency=currency,
+                                           underlying_asset_id=underlying_asset_id,
                                            description=description, country_id=country_id, venue_id=venue_id,
                                            links=links, references=references, issue_date=issue_date,
-                                           expiry_date=expiry_date,
+                                           comments=comments, expiry_date=expiry_date,
                                            *args, **kwargs)
